@@ -357,6 +357,12 @@ class AssignLeaflets(AssignLeafletsBase):
             midplane_sel=midplane_sel,
             midplane_cutoff=midplane_cutoff
         )
+        
+        if not np.allclose(self.u.dimensions[3:], 90.0):
+            raise ValueError("AssignLeaflets requires an orthorhombic box. Please use the on-the-fly "
+                             "transformation :class:`lipyphilic.transformations.triclinic_to_orthorhombic` "
+                             "before calling AssignLeaflets"
+                             )
 
         self.n_bins = n_bins
         self.leaflets = None
