@@ -168,6 +168,12 @@ class ZPositions(base.AnalysisBase):
         self.u = universe
         self.membrane = self.u.select_atoms(lipid_sel, updating=False)
         self._height_atoms = self.u.select_atoms(height_sel, updating=False)
+        
+        if not np.allclose(self.u.dimensions[3:], 90.0):
+            raise ValueError("ZPositions requires an orthorhombic box. Please use the on-the-fly "
+                             "transformation :class:`lipyphilic.transformations.triclinic_to_orthorhombic` "
+                             "before calling ZPositions"
+                             )
             
         # lipid species for which the height in z will be calculated
         self._height_species = np.unique(self._height_atoms.resnames)
