@@ -133,6 +133,12 @@ class ZThickness(base.AnalysisBase):
         self.u = universe
         self.lipids = self.u.select_atoms(lipid_sel, updating=False)
         
+        if not np.allclose(self.u.dimensions[3:], 90.0):
+            raise ValueError("ZThickness requires an orthorhombic box. Please use the on-the-fly "
+                             "transformation :class:`lipyphilic.transformations.triclinic_to_orthorhombic` "
+                             "before calling ZThickness"
+                             )
+        
         # For fancy slicing of atoms for each species
         self.lipid_atom_mask = {species: self.lipids.resnames == species for species in np.unique(self.lipids.resnames)}
         
