@@ -29,12 +29,14 @@ class TestNeighbours:
         # it's a hexagonal lattice
         # with cutoff=12, every lipid should have 6 neighbours
         reference = {
+            'n_frames': 1,
             'n_residues': 100,  # there are 200 atoms but 100 lipids in total
             'n_neighbours': 6,
         }
     
-        assert neighbours.neighbours.shape == (reference['n_residues'], reference['n_residues'])
-        assert (np.sum(neighbours.neighbours.toarray(), axis=0) == reference['n_neighbours']).all()
+        assert neighbours.neighbours.shape[0] == (reference['n_frames'])
+        assert neighbours.neighbours[0].shape == (reference['n_residues'], reference['n_residues'])
+        assert (np.sum(neighbours.neighbours[0].toarray(), axis=0) == reference['n_neighbours']).all()
         
     def test_neighbours_cutoff10(self, universe):
         
@@ -44,12 +46,14 @@ class TestNeighbours:
         # it's a hexagonal lattice, but each hexagon is irregular (two sides longer than the other 4)
         # with cutoff=10, every lipid should have 2 neighbours
         reference = {
+            'n_frames': 1,
             'n_residues': 100,  # there are 200 atoms but 100 lipids in total
             'n_neighbours': 2,
         }
     
-        assert neighbours.neighbours.shape == (reference['n_residues'], reference['n_residues'])
-        assert (np.sum(neighbours.neighbours.toarray(), axis=0) == reference['n_neighbours']).all()
+        assert neighbours.neighbours.shape[0] == (reference['n_frames'])
+        assert neighbours.neighbours[0].shape == (reference['n_residues'], reference['n_residues'])
+        assert (np.sum(neighbours.neighbours[0].toarray(), axis=0) == reference['n_neighbours']).all()
         
     def test_subset_lipids(self, universe):
         
@@ -59,6 +63,7 @@ class TestNeighbours:
         # it's a hexagonal lattice, but each hexagon is irregular (two sides longer than the other 4)
         # with cutoff=10, every lipid should have 2 neighbours
         reference = {
+            'n_frames': 1,
             'n_residues': 50,
             'n_neighbours': np.array(
                 [
@@ -70,9 +75,10 @@ class TestNeighbours:
                 ]
             )
         }
-    
-        assert neighbours.neighbours.shape == (reference['n_residues'], reference['n_residues'])
-        assert_array_equal(np.sum(neighbours.neighbours.toarray(), axis=0), reference['n_neighbours'])
+        
+        assert neighbours.neighbours.shape[0] == (reference['n_frames'])
+        assert neighbours.neighbours[0].shape == (reference['n_residues'], reference['n_residues'])
+        assert_array_equal(np.sum(neighbours.neighbours[0].toarray(), axis=0), reference['n_neighbours'])
 
 
 class TestNeighboursExceptions:
@@ -217,6 +223,43 @@ class TestNeighboursCount:
             neighbours.count_neighbours()
 
 
+class TestNeighboursEnrichment:
+    
+    @staticmethod
+    @pytest.fixture(scope='class')
+    def universe():
+        return MDAnalysis.Universe(HEX_LAT)
+
+    kwargs = {
+        'lipid_sel': 'name L C',
+        'cutoff': 10.0
+    }
+    
+    @pytest.fixture(scope='class')
+    def neighbours(self, universe):
+        neighbours = Neighbours(universe, **self.kwargs)
+        neighbours.run()
+        return neighbours
+        
+    reference = {
+        'n_species': 2,
+        'columns': np.array(["Label", "Frame", "feCHOL", "feLIPI"]),
+        'enrichment': np.array(
+            [
+                [0.4, 1.6],
+                [1.6, 0.4]
+            ])
+    }
+    
+    def test_enrichment_cutoff(self, neighbours):
+        
+        counts, enrichment = neighbours.count_neighbours(return_enrichment=True)
+        
+        assert_array_equal((self.reference['n_species'], self.reference['columns'].size), enrichment.shape)
+        assert_array_equal(self.reference['columns'], enrichment.columns)
+        assert_array_equal(self.reference['enrichment'], enrichment[["feCHOL", "feLIPI"]].values)
+    
+
 class TestNeighboursClusters:
     
     @staticmethod
